Learn R Programming

atime (version 2025.9.30)

atime_versions_remove: Remove packages installed by atime

Description

atime_versions_exprs installs different git versions of a package, and this function removes them. This can be useful if you have changed compilers, which may have different performance characteristics, so you can then re-compile all package versions using the same compiler.

Usage

atime_versions_remove(Package)

Value

integer exit status code from unlink, non-zero if removal failed.

Arguments

Package

Name of package without SHA.

Author

Toby Dylan Hocking

Details

The library searched is the first on .libPaths().