issue107: atime result for issue 107

issue107R Documentation

atime result for issue 107

Description

atime was run on windows, to test a speed and memory increase. Memory increases linearly, but the predict method did not return the correct N value for kilobytes=1e4.

Usage

data("issue107")

Format

List from running atime.

References

https://github.com/Rdatatable/data.table/issues/7687

Examples


data(issue107, package="atime")
refs <- atime::references_best(issue107)
pred <- predict(refs, kilobytes=1e4)
pred$pred
if(requireNamespace("directlabels"))plot(pred)


atime documentation built on April 5, 2026, 1:06 a.m.

Related to issue107 in atime...