| issue107 | R Documentation |
atime was run on windows, to test a speed and memory increase. Memory increases linearly, but the predict method did not return the correct N value for kilobytes=1e4.
data("issue107")
List from running atime.
https://github.com/Rdatatable/data.table/issues/7687
data(issue107, package="atime")
refs <- atime::references_best(issue107)
pred <- predict(refs, kilobytes=1e4)
pred$pred
if(requireNamespace("directlabels"))plot(pred)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.